Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/epubview/epub.py
diff options
context:
space:
mode:
Diffstat (limited to 'epubview/epub.py')
-rw-r--r--epubview/epub.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/epubview/epub.py b/epubview/epub.py
index 9a05abf..560c20a 100644
--- a/epubview/epub.py
+++ b/epubview/epub.py
@@ -137,9 +137,9 @@ class _Epub(object):
def get_info(self):
'''
Returns a EpubInfo object for the open Epub file
'''
- return self._info
+ return self._info.title
def close(self):
'''
@@ -137,9 +137,9 @@ class _Epub(object):
def get_info(self):
'''
- Returns a EpubInfo object for the open Epub file
+ Returns a EpubInfo object title
'''